@@ -267,9 +267,18 @@ class AVISO_fetch(object):
         self.nc.createDimension('latitude', lat.shape[0])
         self.nc.createDimension('longitude', lon.shape[0])
 
-        ncLat = self.nc.createVariable('Lat', 'f4', ('latitude', 'longitude'))
-        ncLon = self.nc.createVariable('Lon', 'f4', ('latitude', 'longitude'))
+        nclat = self.nc.createVariable('latitude', 'f4',
+                ('latitude',))
+        nclon = self.nc.createVariable('longitude', 'f4',
+                ('longitude',))
 
+        ncLat = self.nc.createVariable('Lat', 'f4',
+                ('latitude', 'longitude'))
+        ncLon = self.nc.createVariable('Lon', 'f4',
+                ('latitude', 'longitude'))
+
+        nclat[:] = lat
+        nclon[:] = lon
         ncLat[:] = Lat
         ncLon[:] = Lon
 
@@ -327,9 +336,9 @@ class AVISO_fetch(object):
             self.logger.info("Getting %s" % v)
             #data['h'] = ma.masked_all((len(ti),Lonlimits[-1]-Lonlimits[0], Latlimits[-1]-Latlimits[0]), dtype=numpy.float64)
             #dataset.type.typecode
-            data = self.nc.createVariable(v, 'i4', ('time', 'latitude', 'longitude'),
-                    fill_value=attr['_FillValue'])
-            missing_value = attr['_FillValue']
+            data = self.nc.createVariable(v, 'i2',
+                    ('time', 'latitude', 'longitude'),
+                    fill_value=netCDF4.default_fillvals['i2'])
             #data.missing_value = missing_value
 
             units = attr['units']
@@ -367,10 +376,11 @@ class AVISO_fetch(object):
                                     :Lonlimits[-1]+1]
                             tmp = np.append(tmp1, tmp2, axis=2)
 
+                        ind_valid = tmp != attr['_FillValue']
                         if factor is not None:
-                            ind_valid = tmp != missing_value
                             tmp[ind_valid] = factor * tmp[ind_valid]
 
+                        tmp[~ind_valid] = data._FillValue
                         #data[ind] = tmp.swapaxes(1,2).astype('f')
                         data[ind] = tmp
                         break
@@ -386,6 +396,10 @@ class AVISO_fetch(object):
                 if a not in ['units', '_FillValue']:
                     setattr(data, a, attr[a])
 
+            # !!ATENTION!! Need to check how scale_factor is being defined
+            #   Seems like I do not set it up explicitly, but it's there.
+            setattr(data, "add_offset", 0.)
+
 
 class Products(object):
     """ Calculate some products from the downloaded data
@@ -539,8 +553,8 @@ def mask_shallow(ncfile, zfile, zlimit):
          Use http://opendap.ccst.inpe.br/Misc/etopo2/ETOPO2v2c_f4.nc
     """
     nc = netCDF4.Dataset(ncfile, 'a')
-    Lat = nc.variables['Lat'][:]
-    Lon = nc.variables['Lon'][:]
+    Lat = nc.variables['latitude'][:]
+    Lon = nc.variables['longitude'][:]
 
     #Lon,Lat = numpy.meshgrid(self.data['lon'],self.data['lat'])
     from fluid.common.common import get_bathymery
